/*
 * gedit-recent.c
 * This file is part of gedit
 *
 * Copyright (C) 2002 - James Willcox 
 * Copyright (C) 2003-2005 - Paolo Maggi 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA.
 */
 
/*
 * Modified by the gedit Team, 2002-2005. See the AUTHORS file for a 
 * list of people on the gedit Team.  
 * See the ChangeLog files for a list of changes. 
 *
 * $Id: gedit-recent.c,v 1.24 2005/12/12 17:27:55 pborelli Exp $
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "gedit-recent.h"
#include "gedit-prefs-manager-app.h"

static EggRecentModel *model;

EggRecentModel *
gedit_recent_get_model (void)
{
	return model;
}

void
gedit_recent_init (void)
{
	model = egg_recent_model_new (EGG_RECENT_MODEL_SORT_MRU);
	egg_recent_model_set_limit (model,
				    gedit_prefs_manager_get_max_recents ());

	egg_recent_model_set_filter_groups (model, "gedit", NULL);
}

static gboolean
add_recent_file_real (const gchar *uri)
{
	EggRecentItem *item;

	item = egg_recent_item_new_from_uri (uri);

	egg_recent_item_add_group (item, "gedit");
	egg_recent_model_add_full (model, item);
	egg_recent_item_unref (item);

	return FALSE;
}

void
gedit_recent_add (const gchar *uri)
{
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
			 (GSourceFunc)add_recent_file_real,
			 g_strdup (uri),
			 (GDestroyNotify)g_free);
}

static gboolean
remove_recent_file_real (const gchar *uri)
{
	egg_recent_model_delete (model, uri);

	return FALSE;
}

void
gedit_recent_remove (const gchar *uri)
{
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
			 (GSourceFunc)remove_recent_file_real,
			 g_strdup (uri),
			 (GDestroyNotify)g_free);
}
